[asterisk-commits] jrose: branch 1.8 r401786 - /branches/1.8/main/jitterbuf.c

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Thu Oct 24 14:39:50 CDT 2013


Author: jrose
Date: Thu Oct 24 14:39:49 2013
New Revision: 401786

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=401786
Log:
jitterbuf: Fix memory leak on jitter buffer reset

(issue ASTERISK-22467)
Reported by: Corey Farrell
Patches:
    jitterbuf-jb_reset-leak-1.8.patch
    jitterbuf-jb_reset-leak-11up.patch

Modified:
    branches/1.8/main/jitterbuf.c

Modified: branches/1.8/main/jitterbuf.c
URL: http://svnview.digium.com/svn/asterisk/branches/1.8/main/jitterbuf.c?view=diff&rev=401786&r1=401785&r2=401786
==============================================================================
--- branches/1.8/main/jitterbuf.c (original)
+++ branches/1.8/main/jitterbuf.c Thu Oct 24 14:39:49 2013
@@ -71,12 +71,14 @@
 	jb->info.losspct = (499 * jb->info.losspct)/500;    
 }
 
-void jb_reset(jitterbuf *jb) 
-{
-	/* only save settings */
+void jb_reset(jitterbuf *jb)
+{
+	/* only save settings and free list */
 	jb_conf s = jb->info.conf;
+	jb_frame *fr = jb->free;
 	memset(jb, 0, sizeof(*jb));
 	jb->info.conf = s;
+	jb->free = fr;
 
 	/* initialize length, using the default value */
 	jb->info.current = jb->info.target = jb->info.conf.target_extra = JB_TARGET_EXTRA;
@@ -87,7 +89,7 @@
 {
 	jitterbuf *jb;
 
-	if (!(jb = ast_malloc(sizeof(*jb)))) 
+	if (!(jb = ast_calloc(1, sizeof(*jb))))
 		return NULL;
 
 	jb_reset(jb);




More information about the asterisk-commits mailing list